# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .webhooks import Webhooks


class WebhookResult(UniversalBaseModel):
    """
    Response containing all webhooks that match the requested identifiers.
    Only includes the essential webhook information needed for identification and management.
    """

    webhooks: typing.List[Webhooks] = pydantic.Field()
    """
    List of webhooks.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
