# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ....types.message_schedule import MessageSchedule
from ....types.tracking import Tracking


class SendSmsOptions(UniversalBaseModel):
    """
    Additional settings to customize SMS delivery.
    """

    schedule: typing.Optional[MessageSchedule] = None
    tracking: typing.Optional[Tracking] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
