# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class RcsCampaignOptOutKeywords(UniversalBaseModel):
    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Message sent when a user opt-out. Must include brand name, acknowledge opt-out request and state user will not receive further messages. No marketing or re-engagement attempts.<br>
    
    Recommended format: "You've been unsubscribed from [Agent Name] and will no longer receive messages. If you ever change your mind, reply START or SUBSCRIBE to rejoin anytime."
    """

    keywords: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Keywords that trigger opt-out response (END, UNSUBSCRIBE, STOP, etc).
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
